@@ -14,13 +14,13 @@ class TestDynamics:
         p2 = (5e-9, 5e-9, 3e-9)
         self.region = df.Region(p1=p1, p2=p2)
         self.n = (10, 10, 10)
-        self.subregions = {'r1': df.Region(p1=(-5e-9, -5e-9, -3e-9),
-                                           p2=(5e-9, 0, 3e-9)),
-                           'r2': df.Region(p1=(-5e-9, 0, -3e-9),
-                                           p2=(5e-9, 5e-9, 3e-9))}
+        self.subregions = {
+            "r1": df.Region(p1=(-5e-9, -5e-9, -3e-9), p2=(5e-9, 0, 3e-9)),
+            "r2": df.Region(p1=(-5e-9, 0, -3e-9), p2=(5e-9, 5e-9, 3e-9)),
+        }
 
     def test_scalar_scalar(self):
-        name = 'dynamics_scalar_scalar'
+        name = "dynamics_scalar_scalar"
 
         H = (0, 0, 1e6)
         alpha = 1
@@ -31,8 +31,7 @@ class TestDynamics:
 
         system = mm.System(name=name)
         system.energy = mm.Zeeman(H=H)
-        system.dynamics = (mm.Precession(gamma0=gamma0) +
-                           mm.Damping(alpha=alpha))
+        system.dynamics = mm.Precession(gamma0=gamma0) + mm.Damping(alpha=alpha)
         system.m = df.Field(mesh, dim=3, value=(0, 0.1, 1), norm=Ms)
 
         td = self.calculator.TimeDriver()
@@ -40,25 +39,23 @@ class TestDynamics:
 
         # Alpha is zero, nothing should change.
         value = system.m(mesh.region.random_point())
-        assert np.linalg.norm(np.subtract(value, (0, 0, Ms))) < 1e-3
+        assert np.linalg.norm(np.subtract(np.divide(value, Ms), (0, 0, 1))) < 1e-5
 
         self.calculator.delete(system)
 
     def test_scalar_dict(self):
-        name = 'dynamics_scalar_dict'
+        name = "dynamics_scalar_dict"
 
         H = (0, 0, 1e6)
         gamma0 = 2.211e5
-        alpha = {'r1': 0, 'r2': 1}
+        alpha = {"r1": 0, "r2": 1}
         Ms = 1e6
 
-        mesh = df.Mesh(region=self.region, n=self.n,
-                       subregions=self.subregions)
+        mesh = df.Mesh(region=self.region, n=self.n, subregions=self.subregions)
 
         system = mm.System(name=name)
         system.energy = mm.Zeeman(H=H)
-        system.dynamics = (mm.Precession(gamma0=gamma0) +
-                           mm.Damping(alpha=alpha))
+        system.dynamics = mm.Precession(gamma0=gamma0) + mm.Damping(alpha=alpha)
         system.m = df.Field(mesh, dim=3, value=(0, 0.1, 1), norm=Ms)
 
         td = self.calculator.TimeDriver()
@@ -70,12 +67,12 @@ class TestDynamics:
 
         # alpha!=0 region
         value = system.m((1e-9, 4e-9, 3e-9))
-        assert np.linalg.norm(np.subtract(value, (0, 0, Ms))) < 1e-3
+        assert np.linalg.norm(np.subtract(np.divide(value, Ms), (0, 0, 1))) < 1e-5
 
         self.calculator.delete(system)
 
     def test_field_field(self):
-        name = 'dynamics_field_field'
+        name = "dynamics_field_field"
 
         mesh = df.Mesh(region=self.region, n=self.n)
 
@@ -100,8 +97,7 @@ class TestDynamics:
 
         system = mm.System(name=name)
         system.energy = mm.Zeeman(H=H)
-        system.dynamics = (mm.Precession(gamma0=gamma0) +
-                           mm.Damping(alpha=alpha))
+        system.dynamics = mm.Precession(gamma0=gamma0) + mm.Damping(alpha=alpha)
         system.m = df.Field(mesh, dim=3, value=(0, 0.1, 1), norm=Ms)
 
         td = self.calculator.TimeDriver()
@@ -109,10 +105,10 @@ class TestDynamics:
 
         # alpha=0 and gamma=0 region
         value = system.m((1e-9, -4e-9, 3e-9))
-        assert np.linalg.norm(np.cross(value, (0, 0.1*Ms, Ms))) < 1e-3
+        assert np.linalg.norm(np.cross(value, (0, 0.1 * Ms, Ms))) < 1e-3
 
         # alpha!=0 and gamma!=0 region
         value = system.m((1e-9, 4e-9, 3e-9))
-        assert np.linalg.norm(np.subtract(value, (0, 0, Ms))) < 1e-3
+        assert np.linalg.norm(np.subtract(np.divide(value, Ms), (0, 0, 1))) < 1e-5
 
         self.calculator.delete(system)
